# Helpers and Plotting

(converting-and-structuring)=
## Importing and Converting From Old Versions

```{eval-rst}
.. autofunction:: wombat.core.library.load_yaml

.. autofunction:: wombat.core.library.create_library_structure

.. autofunction:: wombat.core.library.convert_failure_data
```

(plotting)=
## Plotting

```{eval-rst}
.. automodule:: wombat.utilities.plot
   :members:
   :undoc-members:
```

## Logging functions

```{eval-rst}
.. automodule:: wombat.utilities.logging
   :members:
   :undoc-members:
```

## Time Calculations

```{eval-rst}
.. automodule:: wombat.utilities.time
   :members:
   :undoc-members:
```

## Miscellaneous

```{eval-rst}
.. automodule:: wombat.utilities.utilities
   :members:
   :undoc-members:
```
